@@ -133,14 +133,12 @@ class QLabeledSlider(_SliderProxy, QAbstractSlider):
     _slider: QSlider
 
     @overload
-    def __init__(self, parent: QWidget | None = ...) -> None:
-        ...
+    def __init__(self, parent: QWidget | None = ...) -> None: ...
 
     @overload
     def __init__(
         self, orientation: Qt.Orientation, parent: QWidget | None = ...
-    ) -> None:
-        ...
+    ) -> None: ...
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         parent, orientation = _handle_overloaded_slider_sig(args, kwargs)
@@ -263,14 +261,12 @@ class QLabeledDoubleSlider(QLabeledSlider):
     _frangeChanged = Signal(float, float)
 
     @overload
-    def __init__(self, parent: QWidget | None = ...) -> None:
-        ...
+    def __init__(self, parent: QWidget | None = ...) -> None: ...
 
     @overload
     def __init__(
         self, orientation: Qt.Orientation, parent: QWidget | None = ...
-    ) -> None:
-        ...
+    ) -> None: ...
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         super().__init__(*args, **kwargs)
@@ -300,14 +296,12 @@ class QLabeledRangeSlider(_SliderProxy, QAbstractSlider):
     _slider: QRangeSlider
 
     @overload
-    def __init__(self, parent: QWidget | None = ...) -> None:
-        ...
+    def __init__(self, parent: QWidget | None = ...) -> None: ...
 
     @overload
     def __init__(
         self, orientation: Qt.Orientation, parent: QWidget | None = ...
-    ) -> None:
-        ...
+    ) -> None: ...
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         parent, orientation = _handle_overloaded_slider_sig(args, kwargs)
@@ -545,14 +539,12 @@ class QLabeledDoubleRangeSlider(QLabeledRangeSlider):
     _frangeChanged = Signal(float, float)
 
     @overload
-    def __init__(self, parent: QWidget | None = ...) -> None:
-        ...
+    def __init__(self, parent: QWidget | None = ...) -> None: ...
 
     @overload
     def __init__(
         self, orientation: Qt.Orientation, parent: QWidget | None = ...
-    ) -> None:
-        ...
+    ) -> None: ...
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         super().__init__(*args, **kwargs)
